==> haskell-process-extras-0.7.4-401-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-6jRrdSya0m5EjHMrxV87ca
key:                  process-extras-0.7.4-6jRrdSya0m5EjHMrxV87ca
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  565892d6850952dabfe4a28a4c6d9ba8
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/process-extras-0.7.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-process-extras
hs-libraries:         HSprocess-extras-0.7.4-6jRrdSya0m5EjHMrxV87ca
depends:
    ListLike-4.7.8.4-JLZU22CmsDZ1fZfsMJPDhR base-4.17.2.1
    bytestring-0.11.5.3 data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd
    deepseq-1.4.8.0 generic-deriving-1.14.6-Fi77Ihg0HS1HZkSjkLdPmw
    mtl-2.2.2 process-1.6.18.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.4-402-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-7x1ssyeO84s8Op8G5J8gSM
key:                  process-extras-0.7.4-7x1ssyeO84s8Op8G5J8gSM
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  410e7e757764eea7c3ce1c2ecf0d0503
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/process-extras-0.7.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-process-extras
hs-libraries:         HSprocess-extras-0.7.4-7x1ssyeO84s8Op8G5J8gSM
depends:
    ListLike-4.7.8.4-CBdrOAhxN921kXmiwbgkNa base-4.17.2.1
    bytestring-0.11.5.3 data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd
    deepseq-1.4.8.0 generic-deriving-1.14.6-LdN0QvxNAbwL1fAoUFEKmP
    mtl-2.2.2 process-1.6.18.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
